Port Status

| Port | Portstatus | Geschwindigkeit | Verbindungsgeschwindigkeit | Flusssteuerung | Max. MTU
| 1 | Inaktiv | Auto | Nicht verbunden | Deaktiviert | 9702
| 2 | Aktiv | Auto | 1000M | Deaktiviert | 9702
| 3 | Aktiv | Auto | 1000M | Deaktiviert | 9702
| 4 | Inaktiv | Auto | Nicht verbunden | Deaktiviert | 9702
| 5 | Aktiv | Auto | 1000M | Deaktiviert | 9702
| 6 | Aktiv | Auto | 1000M | Deaktiviert | 9702
| 7 | Aktiv | Auto | 1000M | Deaktiviert | 9702
| 8 | Inaktiv | Auto | Nicht verbunden | Deaktiviert | 9702